@@ -71,10 +71,10 @@ def cluster_basic_stats(
     # density related calcs based on nodecount and max possible number of edges in an undirected graph
 
     output = output.withColumn(
-        "maxNumberOfEdgesundir", f.col("nodecount") * (f.col("nodecount") - 1.0) / 2.0,
+        "maxNumberOfEdgesundir", f.expr("(nodecount*(nodecount-1))/2")
     )
     output = output.withColumn(
-        "density", f.round(f.col("edgecount") / f.col("maxNumberOfEdgesundir"), 3)
+        "density", f.expr("edgecount/maxNumberOfEdgesundir") 
     ).drop("sources", "destinations", "maxNumberOfEdgesundir")
     output = output.withColumnRenamed(cluster_id_colname, "cluster_id")
 
@@ -85,12 +85,12 @@ def cluster_graph_hash(sparkdf, src="src", dst="dst", cluster_id_colname="cluste
     """calculate weisfeiler-lehman graph hash of a cluster
 
 
-        Args:
-            sparkdf: imput edgelist Spark DataFrame
-            src: src column name
-            dst: dst column name
-            cluster_id_colname: Graphframes-created connected components created cluster_id
-            """
+    Args:
+        sparkdf: imput edgelist Spark DataFrame
+        src: src column name
+        dst: dst column name
+        cluster_id_colname: Graphframes-created connected components created cluster_id
+    """
     psrc = src
     pdst = dst
 
@@ -110,7 +110,13 @@ def cluster_graph_hash(sparkdf, src="src", dst="dst", cluster_id_colname="cluste
         h = nx.weisfeiler_lehman_graph_hash(nxGraph)
         co = pdf[cluster_id_colname].iloc[0]  # access component id
 
-        return pd.DataFrame([[co] + [h]], columns=["cluster_id", "graphhash",],)
+        return pd.DataFrame(
+            [[co] + [h]],
+            columns=[
+                "cluster_id",
+                "graphhash",
+            ],
+        )
 
     out = sparkdf.groupby(cluster_id_colname).apply(gh)
     return out
@@ -200,7 +206,10 @@ def cluster_main_stats(sparkdf, src="src", dst="dst", cluster_id_colname="cluste
 
 
 def cluster_connectivity_stats(
-    sparkdf, src="src", dst="dst", cluster_id_colname="cluster_id",
+    sparkdf,
+    src="src",
+    dst="dst",
+    cluster_id_colname="cluster_id",
 ):
     """outputs connectivity metrics per cluster_id
 
@@ -250,6 +259,7 @@ def cluster_connectivity_stats(
                 StructField("cluster_id", LongType()),
                 StructField("node_conn", IntegerType()),
                 StructField("edge_conn", IntegerType()),
+                StructField("degeneracy", IntegerType()),
             ]
         ),
         functionType=PandasUDFType.GROUPED_MAP,
@@ -260,11 +270,13 @@ def cluster_connectivity_stats(
         nxGraph = nx.from_pandas_edgelist(pdf, psrc, pdst)
         nc = nx.algorithms.node_connectivity(nxGraph)
         ec = nx.algorithms.edge_connectivity(nxGraph)
+        dg = max(nx.core_number(nxGraph).values())
 
         co = pdf[cluster_id_colname].iloc[0]  # access component id
 
         return pd.DataFrame(
-            [[co] + [nc] + [ec]], columns=["cluster_id", "node_conn", "edge_conn",],
+            [[co] + [nc] + [ec] + [dg]],
+            columns=["cluster_id", "node_conn", "edge_conn", "degeneracy"],
         )
 
     out = sparkdf.groupby(cluster_id_colname).apply(conn_eff)
@@ -371,7 +383,11 @@ def cluster_eb_modularity(
             co_eb_mod = -1.0
 
         return pd.DataFrame(
-            [[co] + [co_eb_mod]], columns=["cluster_id", "cluster_eb_modularity",],
+            [[co] + [co_eb_mod]],
+            columns=[
+                "cluster_id",
+                "cluster_eb_modularity",
+            ],
         )
 
     out = sparkdf.groupby(cluster_id_colname).apply(cluster_eb_m)
@@ -460,7 +476,11 @@ def cluster_lpg_modularity(
         co_lpg_mod = nx_comm.modularity(nxGraph, gn)
 
         return pd.DataFrame(
-            [[co] + [co_lpg_mod]], columns=["cluster_id", "cluster_lpg_modularity",],
+            [[co] + [co_lpg_mod]],
+            columns=[
+                "cluster_id",
+                "cluster_lpg_modularity",
+            ],
         )
 
     out = sparkdf.groupby(cluster_id_colname).apply(cluster_lpg_m)
@@ -550,8 +570,6 @@ def number_of_bridges(
     sparkdf,
     src="src",
     dst="dst",
-    weight_colname="weight",
-    distance_colname="distance",
     cluster_id_colname="cluster_id",
 ):
 
@@ -561,7 +579,6 @@ def number_of_bridges(
             sparkdf: imput edgelist Spark DataFrame
             src: src column name
             dst: dst column name
-            distance_colname: distance column name
             cluster_id_colname: Graphframes-created connected components created cluster_id
 
      Returns:
@@ -572,17 +589,17 @@ def number_of_bridges(
 
     example input spark dataframe
 
-    |src|dst|weight|cluster_id|distance|
-    +---|---|------|----------|--------|
-    |  f|  d|  0.67|         0|0.329   |
-    |  f|  g|  0.34|         0|0.659   |
-    |  b|  c|  0.56|8589934592| 0.439  |
-    |  g|  h|  0.99|         0|0.010   |
-    |  a|  b|   0.4|8589934592|0.6     |
-    |  h|  i|   0.5|         0|0.5     |
-    |  h|  j|   0.8|         0| 0.199  |
-    |  d|  e|  0.84|         0| 0.160  |
-    |  e|  f|  0.65|         0|0.35    |
+    |src|dst|cluster_id|
+    +---|---|----------|
+    |  f|  d|         0|
+    |  f|  g|         0|
+    |  b|  c|8589934592|
+    |  g|  h|         0|
+    |  a|  b|8589934592|
+    |  h|  i|         0|
+    |  h|  j|         0|
+    |  d|  e|         0|
+    |  e|  f|         0|
 
 
     example output spark dataframe
@@ -597,8 +614,6 @@ def number_of_bridges(
     """
     psrc = src
     pdst = dst
-    pweight = weight_colname
-    pdistance = distance_colname
     pcomponent = cluster_id_colname
 
     bridgesoutSchema = StructType(
@@ -614,7 +629,7 @@ def number_of_bridges(
         co = pdf[cluster_id_colname].iloc[0]  # access component id
 
         nxGraph = nx.Graph()
-        nxGraph = nx.from_pandas_edgelist(pdf, psrc, pdst, pdistance)
+        nxGraph = nx.from_pandas_edgelist(pdf, psrc, pdst)
 
         b = bridges(nxGraph)
 
@@ -622,7 +637,7 @@ def number_of_bridges(
 
         return pd.DataFrame(data)
 
-    indf = sparkdf.select(psrc, pdst, pweight, pdistance, pcomponent)
+    indf = sparkdf.select(psrc, pdst, pcomponent)
     out = indf.groupby(cluster_id_colname).apply(br_p_udf)
     return out
 
@@ -673,7 +688,7 @@ def cluster_assortativity(
         ),
         functionType=PandasUDFType.GROUPED_MAP,
     )
-    def drt(pdf: pd.DataFrame) -> pd.DataFrame:
+    def asrt(pdf: pd.DataFrame) -> pd.DataFrame:
 
         nxGraph = nx.Graph()
         nxGraph = nx.from_pandas_edgelist(pdf, psrc, pdst)
@@ -688,9 +703,15 @@ def cluster_assortativity(
 
         co = pdf[cluster_id_colname].iloc[0]  # access component id
 
-        return pd.DataFrame([[co] + [r]], columns=["cluster_id", "assortativity",],)
+        return pd.DataFrame(
+            [[co] + [r]],
+            columns=[
+                "cluster_id",
+                "assortativity",
+            ],
+        )
 
-    out = sparkdf.groupby(cluster_id_colname).apply(drt)
+    out = sparkdf.groupby(cluster_id_colname).apply(asrt)
 
     out = out.withColumn("assortativity", f.round(f.col("assortativity"), 3))
 
