@@ -31,7 +31,7 @@ def _create_spark_jars_string():
         )
     else:
         spark_jars_string = sitestr + "jars/graphframes-0.8.0-spark3.0-s_2.12"
-    return spark_jars_string
+    return spark_jars_string.replace(" ", "")
 
 
 def _graphharmoniser(sparkdf, colsrc, coldst):
@@ -247,11 +247,15 @@ def _from_weighted_graphframe_to_nxGraph(g):
 
 # read a directory of edgelist files and import them into networkx graphs
 def read_edgelists_from_dir(directory):
+
     listofnxgraphs = []
+    if "/" in directory:
+        directory = directory.strip("/")
+
     for filename in os.listdir(directory):
         if filename.endswith("edgelist"):
 
-            current_g = nx.read_edgelist(directory + filename)
+            current_g = nx.read_edgelist(directory + "/" + filename)
             relabeled_g = nx.convert_node_labels_to_integers(
                 current_g, first_label=0, ordering="default", label_attribute="node_id"
             )
